@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to hundreds of possible chord progressions
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use strict;
 use warnings;
@@ -80,9 +80,9 @@ sub transpose {
     @note_map{ get_scale_notes('C', $scale) } = get_scale_notes($note, $scale);
 
     # transpose the progression chords from C
-    (my $named = $progression->[0]) =~ s/([A-G][#b]?)/$note_map{$1}/g;
+    $progression =~ s/([A-G][#b]?)/$note_map{$1}/g;
 
-    return $named;
+    return $progression;
 }
 
 1;
@@ -99,7 +99,7 @@ Data::Dataset::ChordProgressions - Provide access to hundreds of possible chord
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -109,9 +109,7 @@ version 0.0300
   my @data = as_list();
   my %data = as_hash();
 
-  my $named = transpose(
-    'A', 'major', ['C-F-Am-F', 'I-IV-vi-IV']
-  );
+  my $named = transpose('A', 'major', 'C-F-Am-F');
 
 =head1 DESCRIPTION
 
@@ -161,11 +159,8 @@ Return the data as a hash.
 Transpose a B<progression> in the key of C<C> to the given B<note> and
 B<scale>.
 
-The progression must be the array-reference value of
-C<$data{$style}{$scale}{$section}>, as given by the C<as_hash()>
-function, and having the form of, for example:
-
-  [ 'C-F-Am-F', 'I-IV-vi-IV' ]
+The progression must be a string of hyphen-separated chord
+names. For example: C<'C-F-Am-F'>
 
 =head1 AUTHOR
 
